{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Set Replica as Active" %}{% endblock %}

{% block main %}
    {% include 'project/shares/replicas/_set_replica_as_active.html' %}
{% endblock %}
