{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}
{% block modal-body-right %}
<div>
    Please, choose a name for the new share group snapshot,
    that will be created from <b>'{{ share_group_name }}'</b> share group.
</div>
{% endblock %}
