{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Edit Rule Metadata" %}{% endblock %}

{% block main %}
    {% include 'project/shares/_update_rule_metadata.html' %}
{% endblock %}
