{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}
{% block modal-body-right %}
  <h3>{% trans "Description:" %}</h3>
  <p>{% blocktrans trimmed %}
    "Manage" an existing share from a Manila host.
    This will make the share visible within OpenStack.
    <br>
    <br>
    This is equivalent to the <tt>'manila manage'</tt> command.
    {% endblocktrans %}
  </p>
{% endblock %}
