{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block form_id %}{% endblock %}
{% block form_action %}{% url 'horizon:project:share_networks:share_network_update' share_network.id %}{% endblock %}

{% block modal_id %}update_share_network_modal{% endblock %}
{% block modal-header %}{% trans "Edit Share network" %}{% endblock %}

{% block modal-body %}
  <div class="left">
    <fieldset>
    {% include "horizon/common/_form_fields.html" %}
    </fieldset>
  </div>
  <div class="right">
    <h3>{% trans "Description" %}:</h3>
    <p>{% trans "From here you can modify name and description of a share network." %}</p>
  </div>
{% endblock %}

{% block modal-footer %}
  <input class="btn btn-primary pull-right" type="submit" value="{% trans "Edit Share Network" %}" />
  <a href="{% url 'horizon:project:share_networks:index' %}" class="btn secondary cancel close">{% trans "Cancel" %}</a>
{% endblock %}
