{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Manage Share Group Type Access" %}{% endblock %}

{% block main %}
    {% include 'admin/share_group_types/_manage_access.html' %}
{% endblock %}
